@@ -61,6 +61,9 @@ typedef void (*GWeatherInfoFunc) (GWeatherInfo *info, gpointer data);
 GType                    gweather_info_get_type            (void) G_GNUC_CONST;
 GWeatherInfo *           gweather_info_new                 (GWeatherLocation *location,
 							    GWeatherForecastType forecast_type);
+GWeatherInfo *           gweather_info_new_for_world       (GWeatherLocation *world,
+							    GWeatherLocation *location,
+							    GWeatherForecastType forecast_type);
 void                     gweather_info_update              (GWeatherInfo *info);
 void			 gweather_info_abort		   (GWeatherInfo *info);
 
@@ -196,12 +199,12 @@ gboolean gweather_info_get_value_sunset 	(GWeatherInfo *info, time_t *value);
 gboolean gweather_info_get_value_moonphase      (GWeatherInfo *info, GWeatherMoonPhase *value, GWeatherMoonLatitude *lat);
 gboolean gweather_info_get_upcoming_moonphases  (GWeatherInfo *info, time_t *phases);
 
+typedef struct _GWeatherConditions GWeatherConditions;
 struct _GWeatherConditions {
     gboolean significant;
     GWeatherConditionPhenomenon phenomenon;
     GWeatherConditionQualifier qualifier;
 };
-typedef struct _GWeatherConditions GWeatherConditions;
 
 const gchar * gweather_conditions_to_string (GWeatherConditions *conditions);
 
